@@ -1,20 +1,7 @@
 /*  This file is part of the KDE libraries
-    Copyright (C) 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kio_archivebase.h"
@@ -49,8 +36,8 @@ using namespace KIO;
 
 ArchiveProtocolBase::ArchiveProtocolBase( const QByteArray &proto, const QByteArray &pool, const QByteArray &app ) : SlaveBase( proto, pool, app )
 {
-  qCDebug(KIO_ARCHIVE_LOG);
-  m_archiveFile = nullptr;
+    qCDebug(KIO_ARCHIVE_LOG);
+    m_archiveFile = nullptr;
 }
 
 ArchiveProtocolBase::~ArchiveProtocolBase()
@@ -72,7 +59,7 @@ bool ArchiveProtocolBase::checkNewFile( const QUrl & url, QString & path, KIO::E
     {
         // Has it changed ?
         QT_STATBUF statbuf;
-        if ( QT_STAT( QFile::encodeName( m_archiveName ), &statbuf ) == 0 )
+        if ( QT_STAT( QFile::encodeName(m_archiveName).constData(), &statbuf ) == 0 )
         {
             if ( m_mtime == statbuf.st_mtime )
             {
@@ -97,25 +84,24 @@ bool ArchiveProtocolBase::checkNewFile( const QUrl & url, QString & path, KIO::E
     QString archiveFile;
     path.clear();
 
-    int len = fullPath.length();
-    if ( len != 0 && fullPath[ len - 1 ] != '/' )
-        fullPath += '/';
+    if (!fullPath.isEmpty() && !fullPath.endsWith(QLatin1Char('/')))
+        fullPath += QLatin1Char('/');
 
     qCDebug(KIO_ARCHIVE_LOG) << "the full path is" << fullPath;
     QT_STATBUF statbuf;
     statbuf.st_mode = 0; // be sure to clear the directory bit
-    while ( (pos=fullPath.indexOf( '/', pos+1 )) != -1 )
+    while ( (pos=fullPath.indexOf(QLatin1Char('/'), pos+1 )) != -1 )
     {
         QString tryPath = fullPath.left( pos );
         qCDebug(KIO_ARCHIVE_LOG) << fullPath << "trying" << tryPath;
-        if ( QT_STAT( QFile::encodeName(tryPath), &statbuf ) == -1 )
+        if ( QT_STAT( QFile::encodeName(tryPath).constData(), &statbuf ) == -1 )
         {
             if (errno == ENOENT)
             {
                 // The current path is no longer part of the local filesystem.
                 // Either we already have enough of the pathname, or we will
                 // not get anything more useful.
-                statbuf.st_mode = 0;			// do not trust the result
+                statbuf.st_mode = 0;            // do not trust the result
                 break;
             }
 
@@ -141,14 +127,13 @@ bool ArchiveProtocolBase::checkNewFile( const QUrl & url, QString & path, KIO::E
 #endif
             path = fullPath.mid( pos + 1 );
             qCDebug(KIO_ARCHIVE_LOG).nospace() << "fullPath=" << fullPath << " path=" << path;
-            len = path.length();
-            if ( len > 1 )
+            if ( path.length() > 1 )
             {
-                if ( path[ len - 1 ] == '/' )
-                    path.truncate( len - 1 );
+                if (path.endsWith(QLatin1Char('/')))
+                    path.chop(1);
             }
             else
-                path = QString::fromLatin1("/");
+                path = QStringLiteral("/");
             qCDebug(KIO_ARCHIVE_LOG).nospace() << "Found. archiveFile=" << archiveFile << " path=" << path;
             break;
         }
@@ -221,7 +206,12 @@ KIO::StatDetails ArchiveProtocolBase::getStatDetails()
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
     } else {
         const QString sDetails = metaData(QStringLiteral("details"));
+        // silence deprecation warning for KIO::detailsToStatDetails
+        QT_WARNING_PUSH
+        QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+        QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
         details = sDetails.isEmpty() ? KIO::StatDefaultDetails : KIO::detailsToStatDetails(sDetails.toInt());
+        QT_WARNING_POP
     }
 #endif
     return details;
@@ -235,7 +225,7 @@ void ArchiveProtocolBase::createRootUDSEntry( KIO::UDSEntry & entry )
     auto path = m_archiveFile->fileName();
     path = path.mid(path.lastIndexOf(QLatin1Char('/')) + 1);
 
-    entry.fastInsert( KIO::UDSEntry::UDS_NAME, "." );
+    entry.fastInsert( KIO::UDSEntry::UDS_NAME, QStringLiteral(".") );
     entry.fastInsert( KIO::UDSEntry::UDS_DISPLAY_NAME, path );
     entry.fastInsert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR );
     entry.fastInsert( KIO::UDSEntry::UDS_MODIFICATION_TIME, m_mtime );
@@ -281,7 +271,7 @@ void ArchiveProtocolBase::listDir( const QUrl & url )
             // Therefore give a more specific error message
             error( KIO::ERR_SLAVE_DEFINED,
                    i18n( "Could not open the file, probably due to an unsupported file format.\n%1",
-                             url.toDisplayString() ) );
+                         url.toDisplayString() ) );
             return;
         }
         else if ( errorNum != ERR_IS_DIRECTORY )
@@ -306,7 +296,7 @@ void ArchiveProtocolBase::listDir( const QUrl & url )
         QUrl redir;
         redir.setScheme(url.scheme());
         qCDebug(KIO_ARCHIVE_LOG) << "url.path()=" << url.path();
-        redir.setPath( url.path() + QString::fromLatin1("/") );
+        redir.setPath( url.path() + QLatin1Char('/') );
         qCDebug(KIO_ARCHIVE_LOG) << "redirection" << redir.url();
         redirection( redir );
         finished();
@@ -316,7 +306,7 @@ void ArchiveProtocolBase::listDir( const QUrl & url )
     qCDebug(KIO_ARCHIVE_LOG) << "checkNewFile done";
     const KArchiveDirectory* root = m_archiveFile->directory();
     const KArchiveDirectory* dir;
-    if (!path.isEmpty() && path != "/")
+    if (!path.isEmpty() && path != QLatin1String("/"))
     {
         qCDebug(KIO_ARCHIVE_LOG) << "Looking for entry" << path;
         const KArchiveEntry* e = root->entry( path );
@@ -339,7 +329,7 @@ void ArchiveProtocolBase::listDir( const QUrl & url )
     totalSize( l.count() );
 
     UDSEntry entry;
-    if (!l.contains(".")) {
+    if (!l.contains(QLatin1String("."))) {
         createRootUDSEntry(entry);
         listEntry(entry);
     }
@@ -375,7 +365,7 @@ void ArchiveProtocolBase::stat( const QUrl & url )
             // Therefore give a more specific error message
             error( KIO::ERR_SLAVE_DEFINED,
                    i18n( "Could not open the file, probably due to an unsupported file format.\n%1",
-                             url.toDisplayString() ) );
+                         url.toDisplayString() ) );
             return;
         }
         else if ( errorNum != ERR_IS_DIRECTORY )
@@ -396,7 +386,7 @@ void ArchiveProtocolBase::stat( const QUrl & url )
         QString fullPath = url.path();
 #endif
 
-        if ( QT_STAT( QFile::encodeName( fullPath ), &buff ) == -1 )
+        if ( QT_STAT( QFile::encodeName(fullPath).constData(), &buff ) == -1 )
         {
             // Should not happen, as the file was already stated by checkNewFile
             error( KIO::ERR_CANNOT_STAT, url.toDisplayString() );
@@ -419,7 +409,7 @@ void ArchiveProtocolBase::stat( const QUrl & url )
     const KArchiveEntry* archiveEntry;
     if ( path.isEmpty() )
     {
-        path = QString::fromLatin1( "/" );
+        path = QStringLiteral("/");
         archiveEntry = root;
     } else {
         archiveEntry = root->entry( path );
@@ -462,7 +452,7 @@ void ArchiveProtocolBase::get( const QUrl & url )
             // Therefore give a more specific error message
             error( KIO::ERR_SLAVE_DEFINED,
                    i18n( "Could not open the file, probably due to an unsupported file format.\n%1",
-                             url.toDisplayString() ) );
+                         url.toDisplayString() ) );
             return;
         }
         else
@@ -489,13 +479,13 @@ void ArchiveProtocolBase::get( const QUrl & url )
     const KArchiveFile* archiveFileEntry = static_cast<const KArchiveFile *>(archiveEntry);
     if ( !archiveEntry->symLinkTarget().isEmpty() )
     {
-      const QString target = archiveEntry->symLinkTarget();
-      qCDebug(KIO_ARCHIVE_LOG) << "Redirection to" << target;
-      const QUrl realURL = url.resolved(QUrl(target));
-      qCDebug(KIO_ARCHIVE_LOG) << "realURL=" << realURL;
-      redirection( realURL );
-      finished();
-      return;
+        const QString target = archiveEntry->symLinkTarget();
+        qCDebug(KIO_ARCHIVE_LOG) << "Redirection to" << target;
+        const QUrl realURL = url.resolved(QUrl(target));
+        qCDebug(KIO_ARCHIVE_LOG) << "realURL=" << realURL;
+        redirection( realURL );
+        finished();
+        return;
     }
 
     //qCDebug(KIO_ARCHIVE_LOG) << "Preparing to get the archive data";
@@ -512,8 +502,8 @@ void ArchiveProtocolBase::get( const QUrl & url )
     if (!io)
     {
         error( KIO::ERR_SLAVE_DEFINED,
-            i18n( "The archive file could not be opened, perhaps because the format is unsupported.\n%1" ,
-                      url.toDisplayString() ) );
+               i18n( "The archive file could not be opened, perhaps because the format is unsupported.\n%1",
+                     url.toDisplayString() ) );
         return;
     }
 
